# Changelog

## 0.1.0 (2025-05-11)

Full Changelog: [v0.1.0-alpha.8...v0.1.0](https://github.com/privy-io/python-sdk/compare/v0.1.0-alpha.8...v0.1.0)

### Features

* **api:** add fiat.get_status for /v1/users/{user_id}/fiat/status endpoint ([e1c1589](https://github.com/privy-io/python-sdk/commit/e1c15895fa2f134f1d97ec5ac0c8fee46a46eb3f))


### Documentation

* remove a few "APIs" ([#20](https://github.com/privy-io/python-sdk/issues/20)) ([583159c](https://github.com/privy-io/python-sdk/commit/583159c0157c31ce9c0337267a876908c8283aa9))

## 0.1.0-alpha.8 (2025-05-11)

Full Changelog: [v0.1.0-alpha.7...v0.1.0-alpha.8](https://github.com/privy-io/python-sdk/compare/v0.1.0-alpha.7...v0.1.0-alpha.8)

### Features

* **api:** api update ([098e618](https://github.com/privy-io/python-sdk/commit/098e6184ccfa0e89d1fd4f6c58a78d22fe709bbc))
* clean up wallet creation and user signers endpoints ([#19](https://github.com/privy-io/python-sdk/issues/19)) ([3f023ad](https://github.com/privy-io/python-sdk/commit/3f023ada6313401bb0434d20b2499cd39994c731))


### Bug Fixes

* custom user imports and formatting ([7f47551](https://github.com/privy-io/python-sdk/commit/7f475516d811bf7fc4e755faabbab00fbb81c467))
* wire up custom users resource ([bd1c718](https://github.com/privy-io/python-sdk/commit/bd1c7185b9970837cbaffb2c279966c102fb0ef1))

## 0.1.0-alpha.7 (2025-05-11)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/privy-io/python-sdk/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

### Features

* **api:** add get_by_email_address and get_by_jwt_subject_id for users ([3c6327f](https://github.com/privy-io/python-sdk/commit/3c6327f4db24f2d10b910399662a4bab8d63bafa))
* **api:** api update ([4d1f19f](https://github.com/privy-io/python-sdk/commit/4d1f19f5586d7ea6d34b0eb1dc02f9111c646c07))
* **api:** api update ([d6eb8be](https://github.com/privy-io/python-sdk/commit/d6eb8be374614de095a9874a8fddb6d1462e2823))


### Bug Fixes

* **api:** add custom wallets resource ([74d382a](https://github.com/privy-io/python-sdk/commit/74d382a3369cc30144603325417bd38e3f4b4e56))
* **api:** add encryption and decryption logic for user signer endpoints ([583dbef](https://github.com/privy-io/python-sdk/commit/583dbef5973a0313c3173123d2701f65ef5f961e))
* **api:** add encryption and decryption logic for user signer endpoints ([f15edab](https://github.com/privy-io/python-sdk/commit/f15edabfc105a060103ad11aa3bd8544dba14a25))
* **api:** adjust privy wallet interfaces to be the same ([af3c0fa](https://github.com/privy-io/python-sdk/commit/af3c0fa1903e8c705670cca1764197dd6c80d150))
* **api:** simplify user signer authenticate with safe_authenticate_with_jwt method ([f2d5461](https://github.com/privy-io/python-sdk/commit/f2d5461551c2f76753a0dc365279ba5ae14c5cad))
* **api:** support custom privy wallet interfaces on PrivyAPI client ([c113573](https://github.com/privy-io/python-sdk/commit/c11357398abc4326396318edc118e7a99e5e8aa8))
* **package:** support direct resource imports ([4222919](https://github.com/privy-io/python-sdk/commit/4222919a4d1bfcddb5050f7c5f585d04d5a11b94))

## 0.1.0-alpha.6 (2025-05-09)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/privy-io/python-sdk/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** manual updates ([57406b6](https://github.com/privy-io/python-sdk/commit/57406b624d6ef566b6f13a7a0e8ffb0a95242657))


### Bug Fixes

* **api:** manually trigger build ([782a0b7](https://github.com/privy-io/python-sdk/commit/782a0b7221f45d167fbdc82f40dd7df0a9b5dad9))

## 0.1.0-alpha.5 (2025-05-09)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/privy-io/python-sdk/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** manual updates ([83d46a5](https://github.com/privy-io/python-sdk/commit/83d46a5beb437206e050c65bc57ea9950ad30ac8))

## 0.1.0-alpha.4 (2025-05-09)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/privy-io/python-sdk/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** add configure_app method on fiat resource ([1bf85de](https://github.com/privy-io/python-sdk/commit/1bf85deaadda376fa74a6d75feb7079c65d65bb8))
* **api:** api update ([41e929e](https://github.com/privy-io/python-sdk/commit/41e929e49b901782fdaea9e45f806216a58f4b57))


### Chores

* update SDK settings ([a7a26ac](https://github.com/privy-io/python-sdk/commit/a7a26ac0e2dfc9456c014b362c66d37ae6fe5edc))

## 0.1.0-alpha.3 (2025-05-09)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/privy-io/python-sdk/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** rename package name to 'privy' ([07f256e](https://github.com/privy-io/python-sdk/commit/07f256e93d320c54aa1f8f24aa68a6f4452baf8b))

## 0.1.0-alpha.2 (2025-05-09)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/privy-io/python-sdk/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update package names ([3bffca4](https://github.com/privy-io/python-sdk/commit/3bffca498362a213cbf5324174af5954cf27a53e))

## 0.1.0-alpha.1 (2025-05-09)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/privy-io/python-sdk/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** add new fiat endpoints, python package name change, and mintlify code gen ([4a4c2ce](https://github.com/privy-io/python-sdk/commit/4a4c2ce8ee8d372f6fe559742d2f561ee67766ce))
* **api:** api update ([c291977](https://github.com/privy-io/python-sdk/commit/c291977587090a1c2c8b1c12138cfde4b95f84ab))
* **api:** api update ([c05eebd](https://github.com/privy-io/python-sdk/commit/c05eebd31c80bfc90931a12a0755fc8cb871e128))
* **api:** api update ([0cf5f9f](https://github.com/privy-io/python-sdk/commit/0cf5f9f2bc005bc2c8aa16710cef9c965e8856a4))
* **api:** api update ([db04323](https://github.com/privy-io/python-sdk/commit/db04323760627cc7a57888e06a6b4d92ae1794dc))
* **api:** api update ([bbdbf44](https://github.com/privy-io/python-sdk/commit/bbdbf44af8c2919c2c30cb9e25ea03045f00b91e))
* **api:** api update ([a364e98](https://github.com/privy-io/python-sdk/commit/a364e9890dc0a24416fa534be2b2f8d92ac80f35))
* **api:** api update ([30d3023](https://github.com/privy-io/python-sdk/commit/30d3023be7d49b985f66fb10dfc8ebe2cdcf6c3e))


### Bug Fixes

* **api:** manual updates ([cd9d49c](https://github.com/privy-io/python-sdk/commit/cd9d49cc8795791a110b801433d3866f52cca401))
* correctly mark body_wallet_id as optional ([f4e9a90](https://github.com/privy-io/python-sdk/commit/f4e9a90b80c5a5b276f8361650de5d6979740f24))


### Chores

* configure new SDK language ([16981d6](https://github.com/privy-io/python-sdk/commit/16981d64e1565255f61208765dcec9588b0c790e))
* **internal:** avoid errors for isinstance checks on proxies ([599de03](https://github.com/privy-io/python-sdk/commit/599de031ffb06e3977ce8d2596d19946eab30929))
* **internal:** codegen related update ([f9c4341](https://github.com/privy-io/python-sdk/commit/f9c4341e8d13e88de3cc1c8ea366cd791f023842))
* update SDK settings ([25dfe4f](https://github.com/privy-io/python-sdk/commit/25dfe4f762db5b2cd36d2c922c06bfb92ea65f01))
